# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import inter_container_pb2 as voltha__protos_dot_inter__container__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/core.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\030org.opencord.voltha.coreZ,github.com/opencord/voltha-protos/v5/go/core',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18voltha_protos/core.proto\x12\x06voltha\x1a\x1bgoogle/protobuf/empty.proto\x1a#voltha_protos/inter_container.proto\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/device.proto\x1a\x1avoltha_protos/health.proto\"\xf1\x01\n\x14\x44\x65viceTransientState\x12;\n\x0ftransient_state\x18\x01 \x01(\x0e\x32\".voltha.DeviceTransientState.Types\"\x9b\x01\n\x05Types\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\x12\n\x0e\x46ORCE_DELETING\x10\x02\x12\x19\n\x15\x44\x45LETING_FROM_ADAPTER\x10\x03\x12\"\n\x1e\x44\x45LETING_POST_ADAPTER_RESPONSE\x10\x04\x12\x11\n\rDELETE_FAILED\x10\x05\x12\x19\n\x15RECONCILE_IN_PROGRESS\x10\x06\x32\xbb\x0b\n\x0b\x43oreService\x12?\n\x0fGetHealthStatus\x12\x16.google.protobuf.Empty\x1a\x14.voltha.HealthStatus\x12\x46\n\x0fRegisterAdapter\x12\x1b.voltha.AdapterRegistration\x1a\x16.google.protobuf.Empty\x12\x36\n\x0c\x44\x65viceUpdate\x12\x0e.voltha.Device\x1a\x16.google.protobuf.Empty\x12\x33\n\x0bPortCreated\x12\x0c.voltha.Port\x1a\x16.google.protobuf.Empty\x12\x43\n\x10PortsStateUpdate\x12\x17.voltha.PortStateFilter\x1a\x16.google.protobuf.Empty\x12\x34\n\x0e\x44\x65leteAllPorts\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12\x31\n\rGetDevicePort\x12\x12.voltha.PortFilter\x1a\x0c.voltha.Port\x12,\n\x0fListDevicePorts\x12\n.common.ID\x1a\r.voltha.Ports\x12\x46\n\x11\x44\x65viceStateUpdate\x12\x19.voltha.DeviceStateFilter\x1a\x16.google.protobuf.Empty\x12\x41\n\x14\x44\x65vicePMConfigUpdate\x12\x11.voltha.PmConfigs\x1a\x16.google.protobuf.Empty\x12>\n\x13\x43hildDeviceDetected\x12\x17.voltha.DeviceDiscovery\x1a\x0e.voltha.Device\x12\x36\n\x10\x43hildDevicesLost\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12:\n\x14\x43hildDevicesDetected\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12\'\n\tGetDevice\x12\n.common.ID\x1a\x0e.voltha.Device\x12;\n\x0eGetChildDevice\x12\x19.voltha.ChildDeviceFilter\x1a\x0e.voltha.Device\x12.\n\x0fGetChildDevices\x12\n.common.ID\x1a\x0f.voltha.Devices\x12\x38\n\x0cSendPacketIn\x12\x10.voltha.PacketIn\x1a\x16.google.protobuf.Empty\x12\x42\n\x12\x44\x65viceReasonUpdate\x12\x14.voltha.DeviceReason\x1a\x16.google.protobuf.Empty\x12<\n\x0fPortStateUpdate\x12\x11.voltha.PortState\x1a\x16.google.protobuf.Empty\x12;\n\x15ReconcileChildDevices\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12M\n\x1eGetChildDeviceWithProxyAddress\x12\x1b.voltha.Device.ProxyAddress\x1a\x0e.voltha.Device\x12-\n\x08GetPorts\x12\x12.voltha.PortFilter\x1a\r.voltha.Ports\x12H\n\x13\x43hildrenStateUpdate\x12\x19.voltha.DeviceStateFilter\x1a\x16.google.protobuf.Empty\x12\x44\n\x13UpdateImageDownload\x12\x15.voltha.ImageDownload\x1a\x16.google.protobuf.EmptyBH\n\x18org.opencord.voltha.coreZ,github.com/opencord/voltha-protos/v5/go/coreb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,voltha__protos_dot_inter__container__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,voltha__protos_dot_health__pb2.DESCRIPTOR,])



_DEVICETRANSIENTSTATE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.DeviceTransientState.Types',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORCE_DELETING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING_FROM_ADAPTER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING_POST_ADAPTER_RESPONSE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETE_FAILED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECONCILE_IN_PROGRESS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=273,
  serialized_end=428,
)
_sym_db.RegisterEnumDescriptor(_DEVICETRANSIENTSTATE_TYPES)


_DEVICETRANSIENTSTATE = _descriptor.Descriptor(
  name='DeviceTransientState',
  full_name='voltha.DeviceTransientState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transient_state', full_name='voltha.DeviceTransientState.transient_state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEVICETRANSIENTSTATE_TYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=428,
)

_DEVICETRANSIENTSTATE.fields_by_name['transient_state'].enum_type = _DEVICETRANSIENTSTATE_TYPES
_DEVICETRANSIENTSTATE_TYPES.containing_type = _DEVICETRANSIENTSTATE
DESCRIPTOR.message_types_by_name['DeviceTransientState'] = _DEVICETRANSIENTSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeviceTransientState = _reflection.GeneratedProtocolMessageType('DeviceTransientState', (_message.Message,), {
  'DESCRIPTOR' : _DEVICETRANSIENTSTATE,
  '__module__' : 'voltha_protos.core_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceTransientState)
  })
_sym_db.RegisterMessage(DeviceTransientState)


DESCRIPTOR._options = None

_CORESERVICE = _descriptor.ServiceDescriptor(
  name='CoreService',
  full_name='voltha.CoreService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=431,
  serialized_end=1898,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealthStatus',
    full_name='voltha.CoreService.GetHealthStatus',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_health__pb2._HEALTHSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterAdapter',
    full_name='voltha.CoreService.RegisterAdapter',
    index=1,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._ADAPTERREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeviceUpdate',
    full_name='voltha.CoreService.DeviceUpdate',
    index=2,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PortCreated',
    full_name='voltha.CoreService.PortCreated',
    index=3,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PortsStateUpdate',
    full_name='voltha.CoreService.PortsStateUpdate',
    index=4,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._PORTSTATEFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllPorts',
    full_name='voltha.CoreService.DeleteAllPorts',
    index=5,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDevicePort',
    full_name='voltha.CoreService.GetDevicePort',
    index=6,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._PORTFILTER,
    output_type=voltha__protos_dot_device__pb2._PORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDevicePorts',
    full_name='voltha.CoreService.ListDevicePorts',
    index=7,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._PORTS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeviceStateUpdate',
    full_name='voltha.CoreService.DeviceStateUpdate',
    index=8,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._DEVICESTATEFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DevicePMConfigUpdate',
    full_name='voltha.CoreService.DevicePMConfigUpdate',
    index=9,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PMCONFIGS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildDeviceDetected',
    full_name='voltha.CoreService.ChildDeviceDetected',
    index=10,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._DEVICEDISCOVERY,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildDevicesLost',
    full_name='voltha.CoreService.ChildDevicesLost',
    index=11,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildDevicesDetected',
    full_name='voltha.CoreService.ChildDevicesDetected',
    index=12,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDevice',
    full_name='voltha.CoreService.GetDevice',
    index=13,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChildDevice',
    full_name='voltha.CoreService.GetChildDevice',
    index=14,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._CHILDDEVICEFILTER,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChildDevices',
    full_name='voltha.CoreService.GetChildDevices',
    index=15,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._DEVICES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendPacketIn',
    full_name='voltha.CoreService.SendPacketIn',
    index=16,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._PACKETIN,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeviceReasonUpdate',
    full_name='voltha.CoreService.DeviceReasonUpdate',
    index=17,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._DEVICEREASON,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PortStateUpdate',
    full_name='voltha.CoreService.PortStateUpdate',
    index=18,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._PORTSTATE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReconcileChildDevices',
    full_name='voltha.CoreService.ReconcileChildDevices',
    index=19,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChildDeviceWithProxyAddress',
    full_name='voltha.CoreService.GetChildDeviceWithProxyAddress',
    index=20,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE_PROXYADDRESS,
    output_type=voltha__protos_dot_device__pb2._DEVICE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPorts',
    full_name='voltha.CoreService.GetPorts',
    index=21,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._PORTFILTER,
    output_type=voltha__protos_dot_device__pb2._PORTS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildrenStateUpdate',
    full_name='voltha.CoreService.ChildrenStateUpdate',
    index=22,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._DEVICESTATEFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateImageDownload',
    full_name='voltha.CoreService.UpdateImageDownload',
    index=23,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CORESERVICE)

DESCRIPTOR.services_by_name['CoreService'] = _CORESERVICE

# @@protoc_insertion_point(module_scope)
