# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/adapter_services.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import inter_container_pb2 as voltha__protos_dot_inter__container__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
try:
  voltha__protos_dot_ext__config__pb2 = voltha__protos_dot_extensions__pb2.voltha__protos_dot_ext__config__pb2
except AttributeError:
  voltha__protos_dot_ext__config__pb2 = voltha__protos_dot_extensions__pb2.voltha_protos.ext_config_pb2
from voltha_protos import openolt_pb2 as voltha__protos_dot_openolt__pb2
try:
  voltha__protos_dot_tech__profile__pb2 = voltha__protos_dot_openolt__pb2.voltha__protos_dot_tech__profile__pb2
except AttributeError:
  voltha__protos_dot_tech__profile__pb2 = voltha__protos_dot_openolt__pb2.voltha_protos.tech_profile_pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_openolt__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_openolt__pb2.voltha_protos.common_pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_meta__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_meta__pb2
except AttributeError:
  voltha__protos_dot_meta__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.meta_pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
try:
  voltha__protos_dot_health__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_health__pb2
except AttributeError:
  voltha__protos_dot_health__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.health_pb2
try:
  voltha__protos_dot_logical__device__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_logical__device__pb2
except AttributeError:
  voltha__protos_dot_logical__device__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.logical_device_pb2
try:
  voltha__protos_dot_device__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_device__pb2
except AttributeError:
  voltha__protos_dot_device__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.device_pb2
try:
  voltha__protos_dot_adapter__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_adapter__pb2
except AttributeError:
  voltha__protos_dot_adapter__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.adapter_pb2
try:
  voltha__protos_dot_openflow__13__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_openflow__13__pb2
except AttributeError:
  voltha__protos_dot_openflow__13__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.openflow_13_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/adapter_services.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\035org.opencord.adapter_servicesB\025VolthaAdapterServicesZ8github.com/opencord/voltha-protos/v5/go/adapter_services',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$voltha_protos/adapter_services.proto\x12\x06voltha\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1avoltha_protos/common.proto\x1a#voltha_protos/inter_container.proto\x1a\x1avoltha_protos/device.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1bvoltha_protos/openolt.proto\x1a\x1avoltha_protos/health.proto\x1a\x1avoltha_protos/voltha.proto2\xac\x12\n\x0e\x41\x64\x61pterService\x12?\n\x0fGetHealthStatus\x12\x16.google.protobuf.Empty\x1a\x14.voltha.HealthStatus\x12\x35\n\x0b\x41\x64optDevice\x12\x0e.voltha.Device\x1a\x16.google.protobuf.Empty\x12\x39\n\x0fReconcileDevice\x12\x0e.voltha.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0c\x44\x65leteDevice\x12\x0e.voltha.Device\x1a\x16.google.protobuf.Empty\x12\x37\n\rDisableDevice\x12\x0e.voltha.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eReEnableDevice\x12\x0e.voltha.Device\x1a\x16.google.protobuf.Empty\x12\x36\n\x0cRebootDevice\x12\x0e.voltha.Device\x1a\x16.google.protobuf.Empty\x12\x38\n\x0eSelfTestDevice\x12\x0e.voltha.Device\x1a\x16.google.protobuf.Empty\x12<\n\x10GetOfpDeviceInfo\x12\x0e.voltha.Device\x1a\x18.voltha.SwitchCapability\x12\x39\n\x0f\x43hildDeviceLost\x12\x0e.voltha.Device\x1a\x16.google.protobuf.Empty\x12\x32\n\nEnablePort\x12\x0c.voltha.Port\x1a\x16.google.protobuf.Empty\x12\x33\n\x0b\x44isablePort\x12\x0c.voltha.Port\x1a\x16.google.protobuf.Empty\x12<\n\x0fUpdateFlowsBulk\x12\x11.voltha.BulkFlows\x1a\x16.google.protobuf.Empty\x12L\n\x18UpdateFlowsIncrementally\x12\x18.voltha.IncrementalFlows\x1a\x16.google.protobuf.Empty\x12:\n\rSendPacketOut\x12\x11.voltha.PacketOut\x1a\x16.google.protobuf.Empty\x12?\n\x0eUpdatePmConfig\x12\x15.voltha.PmConfigsInfo\x1a\x16.google.protobuf.Empty\x12S\n\x10\x44ownloadOnuImage\x12\".voltha.DeviceImageDownloadRequest\x1a\x1b.voltha.DeviceImageResponse\x12L\n\x11GetOnuImageStatus\x12\x1a.voltha.DeviceImageRequest\x1a\x1b.voltha.DeviceImageResponse\x12O\n\x14\x41\x62ortOnuImageUpgrade\x12\x1a.voltha.DeviceImageRequest\x1a\x1b.voltha.DeviceImageResponse\x12-\n\x0cGetOnuImages\x12\n.common.ID\x1a\x11.voltha.OnuImages\x12K\n\x10\x41\x63tivateOnuImage\x12\x1a.voltha.DeviceImageRequest\x1a\x1b.voltha.DeviceImageResponse\x12I\n\x0e\x43ommitOnuImage\x12\x1a.voltha.DeviceImageRequest\x1a\x1b.voltha.DeviceImageResponse\x12\x44\n\rDownloadImage\x12\x1c.voltha.ImageDownloadMessage\x1a\x15.voltha.ImageDownload\x12M\n\x16GetImageDownloadStatus\x12\x1c.voltha.ImageDownloadMessage\x1a\x15.voltha.ImageDownload\x12J\n\x13\x43\x61ncelImageDownload\x12\x1c.voltha.ImageDownloadMessage\x1a\x15.voltha.ImageDownload\x12J\n\x13\x41\x63tivateImageUpdate\x12\x1c.voltha.ImageDownloadMessage\x1a\x15.voltha.ImageDownload\x12H\n\x11RevertImageUpdate\x12\x1c.voltha.ImageDownloadMessage\x1a\x15.voltha.ImageDownload\x12\x37\n\rStartOmciTest\x12\x10.voltha.OMCITest\x1a\x14.voltha.TestResponse\x12\x44\n\rSimulateAlarm\x12\x1c.voltha.SimulateAlarmMessage\x1a\x15.common.OperationResp\x12<\n\rSuppressEvent\x12\x13.voltha.EventFilter\x1a\x16.google.protobuf.Empty\x12>\n\x0fUnSuppressEvent\x12\x13.voltha.EventFilter\x1a\x16.google.protobuf.Empty\x12?\n\x0bGetExtValue\x12\x1a.voltha.GetExtValueMessage\x1a\x14.common.ReturnValues\x12\x41\n\x0bSetExtValue\x12\x1a.voltha.SetExtValueMessage\x1a\x16.google.protobuf.Empty\x12U\n\x0eGetSingleValue\x12 .extension.SingleGetValueRequest\x1a!.extension.SingleGetValueResponse\x12U\n\x0eSetSingleValue\x12 .extension.SingleSetValueRequest\x1a!.extension.SingleSetValueResponse2\xbc\x03\n\x16OnuInterAdapterService\x12?\n\x0fGetHealthStatus\x12\x16.google.protobuf.Empty\x1a\x14.voltha.HealthStatus\x12\x45\n\rOnuIndication\x12\x1c.voltha.OnuIndicationMessage\x1a\x16.google.protobuf.Empty\x12=\n\x0eOmciIndication\x12\x13.voltha.OmciMessage\x1a\x16.google.protobuf.Empty\x12Q\n\x13\x44ownloadTechProfile\x12\".voltha.TechProfileDownloadMessage\x1a\x16.google.protobuf.Empty\x12\x45\n\rDeleteGemPort\x12\x1c.voltha.DeleteGemPortMessage\x1a\x16.google.protobuf.Empty\x12\x41\n\x0b\x44\x65leteTCont\x12\x1a.voltha.DeleteTcontMessage\x1a\x16.google.protobuf.Empty2\x83\x02\n\x16OltInterAdapterService\x12?\n\x0fGetHealthStatus\x12\x16.google.protobuf.Empty\x1a\x14.voltha.HealthStatus\x12?\n\x10ProxyOmciRequest\x12\x13.voltha.OmciMessage\x1a\x16.google.protobuf.Empty\x12g\n\x16GetTechProfileInstance\x12).voltha.TechProfileInstanceRequestMessage\x1a\".voltha.TechProfileDownloadMessageBp\n\x1dorg.opencord.adapter_servicesB\x15VolthaAdapterServicesZ8github.com/opencord/voltha-protos/v5/go/adapter_servicesb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_inter__container__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,voltha__protos_dot_extensions__pb2.DESCRIPTOR,voltha__protos_dot_openolt__pb2.DESCRIPTOR,voltha__protos_dot_health__pb2.DESCRIPTOR,voltha__protos_dot_voltha__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_ADAPTERSERVICE = _descriptor.ServiceDescriptor(
  name='AdapterService',
  full_name='voltha.AdapterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=288,
  serialized_end=2636,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealthStatus',
    full_name='voltha.AdapterService.GetHealthStatus',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_health__pb2._HEALTHSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AdoptDevice',
    full_name='voltha.AdapterService.AdoptDevice',
    index=1,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReconcileDevice',
    full_name='voltha.AdapterService.ReconcileDevice',
    index=2,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDevice',
    full_name='voltha.AdapterService.DeleteDevice',
    index=3,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisableDevice',
    full_name='voltha.AdapterService.DisableDevice',
    index=4,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReEnableDevice',
    full_name='voltha.AdapterService.ReEnableDevice',
    index=5,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RebootDevice',
    full_name='voltha.AdapterService.RebootDevice',
    index=6,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SelfTestDevice',
    full_name='voltha.AdapterService.SelfTestDevice',
    index=7,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOfpDeviceInfo',
    full_name='voltha.AdapterService.GetOfpDeviceInfo',
    index=8,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=voltha__protos_dot_inter__container__pb2._SWITCHCAPABILITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChildDeviceLost',
    full_name='voltha.AdapterService.ChildDeviceLost',
    index=9,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._DEVICE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EnablePort',
    full_name='voltha.AdapterService.EnablePort',
    index=10,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DisablePort',
    full_name='voltha.AdapterService.DisablePort',
    index=11,
    containing_service=None,
    input_type=voltha__protos_dot_device__pb2._PORT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFlowsBulk',
    full_name='voltha.AdapterService.UpdateFlowsBulk',
    index=12,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._BULKFLOWS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFlowsIncrementally',
    full_name='voltha.AdapterService.UpdateFlowsIncrementally',
    index=13,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._INCREMENTALFLOWS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendPacketOut',
    full_name='voltha.AdapterService.SendPacketOut',
    index=14,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._PACKETOUT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePmConfig',
    full_name='voltha.AdapterService.UpdatePmConfig',
    index=15,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._PMCONFIGSINFO,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadOnuImage',
    full_name='voltha.AdapterService.DownloadOnuImage',
    index=16,
    containing_service=None,
    input_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGEDOWNLOADREQUEST,
    output_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOnuImageStatus',
    full_name='voltha.AdapterService.GetOnuImageStatus',
    index=17,
    containing_service=None,
    input_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AbortOnuImageUpgrade',
    full_name='voltha.AdapterService.AbortOnuImageUpgrade',
    index=18,
    containing_service=None,
    input_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOnuImages',
    full_name='voltha.AdapterService.GetOnuImages',
    index=19,
    containing_service=None,
    input_type=voltha__protos_dot_common__pb2._ID,
    output_type=voltha__protos_dot_device__pb2._ONUIMAGES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateOnuImage',
    full_name='voltha.AdapterService.ActivateOnuImage',
    index=20,
    containing_service=None,
    input_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CommitOnuImage',
    full_name='voltha.AdapterService.CommitOnuImage',
    index=21,
    containing_service=None,
    input_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGEREQUEST,
    output_type=voltha__protos_dot_voltha__pb2._DEVICEIMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadImage',
    full_name='voltha.AdapterService.DownloadImage',
    index=22,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetImageDownloadStatus',
    full_name='voltha.AdapterService.GetImageDownloadStatus',
    index=23,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelImageDownload',
    full_name='voltha.AdapterService.CancelImageDownload',
    index=24,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateImageUpdate',
    full_name='voltha.AdapterService.ActivateImageUpdate',
    index=25,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevertImageUpdate',
    full_name='voltha.AdapterService.RevertImageUpdate',
    index=26,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._IMAGEDOWNLOADMESSAGE,
    output_type=voltha__protos_dot_device__pb2._IMAGEDOWNLOAD,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartOmciTest',
    full_name='voltha.AdapterService.StartOmciTest',
    index=27,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._OMCITEST,
    output_type=voltha__protos_dot_voltha__pb2._TESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SimulateAlarm',
    full_name='voltha.AdapterService.SimulateAlarm',
    index=28,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._SIMULATEALARMMESSAGE,
    output_type=voltha__protos_dot_common__pb2._OPERATIONRESP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SuppressEvent',
    full_name='voltha.AdapterService.SuppressEvent',
    index=29,
    containing_service=None,
    input_type=voltha__protos_dot_voltha__pb2._EVENTFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UnSuppressEvent',
    full_name='voltha.AdapterService.UnSuppressEvent',
    index=30,
    containing_service=None,
    input_type=voltha__protos_dot_voltha__pb2._EVENTFILTER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetExtValue',
    full_name='voltha.AdapterService.GetExtValue',
    index=31,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._GETEXTVALUEMESSAGE,
    output_type=voltha__protos_dot_common__pb2._RETURNVALUES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetExtValue',
    full_name='voltha.AdapterService.SetExtValue',
    index=32,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._SETEXTVALUEMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSingleValue',
    full_name='voltha.AdapterService.GetSingleValue',
    index=33,
    containing_service=None,
    input_type=voltha__protos_dot_extensions__pb2._SINGLEGETVALUEREQUEST,
    output_type=voltha__protos_dot_extensions__pb2._SINGLEGETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetSingleValue',
    full_name='voltha.AdapterService.SetSingleValue',
    index=34,
    containing_service=None,
    input_type=voltha__protos_dot_extensions__pb2._SINGLESETVALUEREQUEST,
    output_type=voltha__protos_dot_extensions__pb2._SINGLESETVALUERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ADAPTERSERVICE)

DESCRIPTOR.services_by_name['AdapterService'] = _ADAPTERSERVICE


_ONUINTERADAPTERSERVICE = _descriptor.ServiceDescriptor(
  name='OnuInterAdapterService',
  full_name='voltha.OnuInterAdapterService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2639,
  serialized_end=3083,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealthStatus',
    full_name='voltha.OnuInterAdapterService.GetHealthStatus',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_health__pb2._HEALTHSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnuIndication',
    full_name='voltha.OnuInterAdapterService.OnuIndication',
    index=1,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._ONUINDICATIONMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OmciIndication',
    full_name='voltha.OnuInterAdapterService.OmciIndication',
    index=2,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._OMCIMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadTechProfile',
    full_name='voltha.OnuInterAdapterService.DownloadTechProfile',
    index=3,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._TECHPROFILEDOWNLOADMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteGemPort',
    full_name='voltha.OnuInterAdapterService.DeleteGemPort',
    index=4,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._DELETEGEMPORTMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTCont',
    full_name='voltha.OnuInterAdapterService.DeleteTCont',
    index=5,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._DELETETCONTMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ONUINTERADAPTERSERVICE)

DESCRIPTOR.services_by_name['OnuInterAdapterService'] = _ONUINTERADAPTERSERVICE


_OLTINTERADAPTERSERVICE = _descriptor.ServiceDescriptor(
  name='OltInterAdapterService',
  full_name='voltha.OltInterAdapterService',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3086,
  serialized_end=3345,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealthStatus',
    full_name='voltha.OltInterAdapterService.GetHealthStatus',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=voltha__protos_dot_health__pb2._HEALTHSTATUS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ProxyOmciRequest',
    full_name='voltha.OltInterAdapterService.ProxyOmciRequest',
    index=1,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._OMCIMESSAGE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTechProfileInstance',
    full_name='voltha.OltInterAdapterService.GetTechProfileInstance',
    index=2,
    containing_service=None,
    input_type=voltha__protos_dot_inter__container__pb2._TECHPROFILEINSTANCEREQUESTMESSAGE,
    output_type=voltha__protos_dot_inter__container__pb2._TECHPROFILEDOWNLOADMESSAGE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OLTINTERADAPTERSERVICE)

DESCRIPTOR.services_by_name['OltInterAdapterService'] = _OLTINTERADAPTERSERVICE

# @@protoc_insertion_point(module_scope)
