# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/inter_container.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_meta__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_meta__pb2
except AttributeError:
  voltha__protos_dot_meta__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.meta_pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
try:
  voltha__protos_dot_health__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_health__pb2
except AttributeError:
  voltha__protos_dot_health__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.health_pb2
try:
  voltha__protos_dot_logical__device__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_logical__device__pb2
except AttributeError:
  voltha__protos_dot_logical__device__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.logical_device_pb2
try:
  voltha__protos_dot_device__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_device__pb2
except AttributeError:
  voltha__protos_dot_device__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.device_pb2
try:
  voltha__protos_dot_adapter__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_adapter__pb2
except AttributeError:
  voltha__protos_dot_adapter__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.adapter_pb2
try:
  voltha__protos_dot_openflow__13__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_openflow__13__pb2
except AttributeError:
  voltha__protos_dot_openflow__13__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.openflow_13_pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2
from voltha_protos import tech_profile_pb2 as voltha__protos_dot_tech__profile__pb2
from voltha_protos import openolt_pb2 as voltha__protos_dot_openolt__pb2
try:
  voltha__protos_dot_tech__profile__pb2 = voltha__protos_dot_openolt__pb2.voltha__protos_dot_tech__profile__pb2
except AttributeError:
  voltha__protos_dot_tech__profile__pb2 = voltha__protos_dot_openolt__pb2.voltha_protos.tech_profile_pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_openolt__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_openolt__pb2.voltha_protos.common_pb2
from voltha_protos import adapter_pb2 as voltha__protos_dot_adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/inter_container.proto',
  package='voltha',
  syntax='proto3',
  serialized_options=b'\n\023org.opencord.volthaZ7github.com/opencord/voltha-protos/v5/go/inter_container',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#voltha_protos/inter_container.proto\x12\x06voltha\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/voltha.proto\x1a\x1fvoltha_protos/openflow_13.proto\x1a voltha_protos/tech_profile.proto\x1a\x1bvoltha_protos/openolt.proto\x1a\x1bvoltha_protos/adapter.proto\x1a\x1avoltha_protos/device.proto\"\\\n\x13\x41\x64\x61pterRegistration\x12 \n\x07\x61\x64\x61pter\x18\x01 \x01(\x0b\x32\x0f.voltha.Adapter\x12#\n\x06\x64Types\x18\x02 \x01(\x0b\x32\x13.voltha.DeviceTypes\"e\n\x11\x43hildDeviceFilter\x12\x11\n\tparent_id\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x0e\n\x06onu_id\x18\x03 \x01(\r\x12\x16\n\x0eparent_port_no\x18\x04 \x01(\r\"W\n\nPortFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12(\n\tport_type\x18\x03 \x01(\x0e\x32\x15.voltha.Port.PortType\"\xa5\x01\n\x0f\x44\x65viceDiscovery\x12\x11\n\tparent_id\x18\x01 \x01(\t\x12\x16\n\x0eparent_port_no\x18\x02 \x01(\r\x12\x19\n\x11\x63hild_device_type\x18\x03 \x01(\t\x12\x12\n\nchannel_id\x18\x04 \x01(\r\x12\x11\n\tvendor_id\x18\x05 \x01(\t\x12\x15\n\rserial_number\x18\x06 \x01(\t\x12\x0e\n\x06onu_id\x18\x07 \x01(\r\"\xa1\x01\n\x11\x44\x65viceStateFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10parent_device_id\x18\x02 \x01(\t\x12-\n\x0boper_status\x18\x03 \x01(\x0e\x32\x18.common.OperStatus.Types\x12\x30\n\x0b\x63onn_status\x18\x04 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\"\x88\x01\n\tPortState\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12(\n\tport_type\x18\x02 \x01(\x0e\x32\x15.voltha.Port.PortType\x12\x0f\n\x07port_no\x18\x03 \x01(\r\x12-\n\x0boper_status\x18\x04 \x01(\x0e\x32\x18.common.OperStatus.Types\"m\n\x0fPortStateFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10port_type_filter\x18\x02 \x01(\r\x12-\n\x0boper_status\x18\x04 \x01(\x0e\x32\x18.common.OperStatus.Types\";\n\x08PacketIn\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0e\n\x06packet\x18\x03 \x01(\x0c\"c\n\tPacketOut\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65gress_port_no\x18\x02 \x01(\r\x12+\n\x06packet\x18\x03 \x01(\x0b\x32\x1b.openflow_13.ofp_packet_out\"1\n\x0c\x44\x65viceReason\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\xa4\x01\n\tBulkFlows\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.voltha.Device\x12!\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x12.openflow_13.Flows\x12\'\n\x06groups\x18\x03 \x01(\x0b\x32\x17.openflow_13.FlowGroups\x12+\n\rflow_metadata\x18\x04 \x01(\x0b\x32\x14.voltha.FlowMetadata\"\xb7\x01\n\x10IncrementalFlows\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.voltha.Device\x12\'\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x18.openflow_13.FlowChanges\x12-\n\x06groups\x18\x03 \x01(\x0b\x32\x1d.openflow_13.FlowGroupChanges\x12+\n\rflow_metadata\x18\x04 \x01(\x0b\x32\x14.voltha.FlowMetadata\"I\n\rPmConfigsInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12%\n\npm_configs\x18\x02 \x01(\x0b\x32\x11.voltha.PmConfigs\"r\n\x10SwitchCapability\x12#\n\x04\x64\x65sc\x18\x01 \x01(\x0b\x32\x15.openflow_13.ofp_desc\x12\x39\n\x0fswitch_features\x18\x02 \x01(\x0b\x32 .openflow_13.ofp_switch_features\"\\\n\x14ImageDownloadMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.voltha.Device\x12$\n\x05image\x18\x02 \x01(\x0b\x32\x15.voltha.ImageDownload\"T\n\x08OMCITest\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.voltha.Device\x12(\n\x07request\x18\x02 \x01(\x0b\x32\x17.voltha.OmciTestRequest\"e\n\x14SimulateAlarmMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.voltha.Device\x12-\n\x07request\x18\x02 \x01(\x0b\x32\x1c.voltha.SimulateAlarmRequest\"\x8d\x01\n\x12GetExtValueMessage\x12%\n\rparent_device\x18\x01 \x01(\x0b\x32\x0e.voltha.Device\x12$\n\x0c\x63hild_device\x18\x02 \x01(\x0b\x32\x0e.voltha.Device\x12*\n\nvalue_type\x18\x03 \x01(\x0e\x32\x16.common.ValueType.Type\"U\n\x12SetExtValueMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.voltha.Device\x12\x1f\n\x05value\x18\x03 \x01(\x0b\x32\x10.voltha.ValueSet\"\xba\x01\n\x0bOmciMessage\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x33\n\x0e\x63onnect_status\x18\x02 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\x12\x32\n\rproxy_address\x18\x03 \x01(\x0b\x32\x1b.voltha.Device.ProxyAddress\x12\x18\n\x10parent_device_id\x18\x04 \x01(\t\x12\x17\n\x0f\x63hild_device_id\x18\x05 \x01(\t\"\xea\x01\n\x1aTechProfileDownloadMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06uni_id\x18\x02 \x01(\r\x12\x18\n\x10tp_instance_path\x18\x03 \x01(\t\x12\x38\n\x0btp_instance\x18\x04 \x01(\x0b\x32!.tech_profile.TechProfileInstanceH\x00\x12\x41\n\x10\x65pon_tp_instance\x18\x05 \x01(\x0b\x32%.tech_profile.EponTechProfileInstanceH\x00\x42\x12\n\x10tech_tp_instance\"h\n\x14\x44\x65leteGemPortMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06uni_id\x18\x02 \x01(\r\x12\x18\n\x10tp_instance_path\x18\x03 \x01(\t\x12\x13\n\x0bgem_port_id\x18\x04 \x01(\r\"c\n\x12\x44\x65leteTcontMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06uni_id\x18\x02 \x01(\r\x12\x18\n\x10tp_instance_path\x18\x03 \x01(\t\x12\x10\n\x08\x61lloc_id\x18\x04 \x01(\r\"Y\n\x14OnuIndicationMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12.\n\x0eonu_indication\x18\x02 \x01(\x0b\x32\x16.openolt.OnuIndication\"\xa3\x01\n!TechProfileInstanceRequestMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10tp_instance_path\x18\x02 \x01(\t\x12\x18\n\x10parent_device_id\x18\x03 \x01(\t\x12\x17\n\x0fparent_pon_port\x18\x04 \x01(\r\x12\x0e\n\x06onu_id\x18\x05 \x01(\r\x12\x0e\n\x06uni_id\x18\x06 \x01(\rBN\n\x13org.opencord.volthaZ7github.com/opencord/voltha-protos/v5/go/inter_containerb\x06proto3'
  ,
  dependencies=[voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_voltha__pb2.DESCRIPTOR,voltha__protos_dot_openflow__13__pb2.DESCRIPTOR,voltha__protos_dot_tech__profile__pb2.DESCRIPTOR,voltha__protos_dot_openolt__pb2.DESCRIPTOR,voltha__protos_dot_adapter__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,])




_ADAPTERREGISTRATION = _descriptor.Descriptor(
  name='AdapterRegistration',
  full_name='voltha.AdapterRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adapter', full_name='voltha.AdapterRegistration.adapter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dTypes', full_name='voltha.AdapterRegistration.dTypes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=348,
)


_CHILDDEVICEFILTER = _descriptor.Descriptor(
  name='ChildDeviceFilter',
  full_name='voltha.ChildDeviceFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='voltha.ChildDeviceFilter.parent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='voltha.ChildDeviceFilter.serial_number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='voltha.ChildDeviceFilter.onu_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_port_no', full_name='voltha.ChildDeviceFilter.parent_port_no', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=451,
)


_PORTFILTER = _descriptor.Descriptor(
  name='PortFilter',
  full_name='voltha.PortFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.PortFilter.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='voltha.PortFilter.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_type', full_name='voltha.PortFilter.port_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=540,
)


_DEVICEDISCOVERY = _descriptor.Descriptor(
  name='DeviceDiscovery',
  full_name='voltha.DeviceDiscovery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='voltha.DeviceDiscovery.parent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_port_no', full_name='voltha.DeviceDiscovery.parent_port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_device_type', full_name='voltha.DeviceDiscovery.child_device_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='voltha.DeviceDiscovery.channel_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor_id', full_name='voltha.DeviceDiscovery.vendor_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='voltha.DeviceDiscovery.serial_number', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='voltha.DeviceDiscovery.onu_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=708,
)


_DEVICESTATEFILTER = _descriptor.Descriptor(
  name='DeviceStateFilter',
  full_name='voltha.DeviceStateFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.DeviceStateFilter.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_device_id', full_name='voltha.DeviceStateFilter.parent_device_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='voltha.DeviceStateFilter.oper_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conn_status', full_name='voltha.DeviceStateFilter.conn_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=872,
)


_PORTSTATE = _descriptor.Descriptor(
  name='PortState',
  full_name='voltha.PortState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.PortState.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_type', full_name='voltha.PortState.port_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='voltha.PortState.port_no', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='voltha.PortState.oper_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=1011,
)


_PORTSTATEFILTER = _descriptor.Descriptor(
  name='PortStateFilter',
  full_name='voltha.PortStateFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.PortStateFilter.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_type_filter', full_name='voltha.PortStateFilter.port_type_filter', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oper_status', full_name='voltha.PortStateFilter.oper_status', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1013,
  serialized_end=1122,
)


_PACKETIN = _descriptor.Descriptor(
  name='PacketIn',
  full_name='voltha.PacketIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.PacketIn.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='voltha.PacketIn.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet', full_name='voltha.PacketIn.packet', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1183,
)


_PACKETOUT = _descriptor.Descriptor(
  name='PacketOut',
  full_name='voltha.PacketOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.PacketOut.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='egress_port_no', full_name='voltha.PacketOut.egress_port_no', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packet', full_name='voltha.PacketOut.packet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1284,
)


_DEVICEREASON = _descriptor.Descriptor(
  name='DeviceReason',
  full_name='voltha.DeviceReason',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.DeviceReason.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='voltha.DeviceReason.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1286,
  serialized_end=1335,
)


_BULKFLOWS = _descriptor.Descriptor(
  name='BulkFlows',
  full_name='voltha.BulkFlows',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='voltha.BulkFlows.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flows', full_name='voltha.BulkFlows.flows', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='voltha.BulkFlows.groups', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_metadata', full_name='voltha.BulkFlows.flow_metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1338,
  serialized_end=1502,
)


_INCREMENTALFLOWS = _descriptor.Descriptor(
  name='IncrementalFlows',
  full_name='voltha.IncrementalFlows',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='voltha.IncrementalFlows.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flows', full_name='voltha.IncrementalFlows.flows', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='voltha.IncrementalFlows.groups', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flow_metadata', full_name='voltha.IncrementalFlows.flow_metadata', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1505,
  serialized_end=1688,
)


_PMCONFIGSINFO = _descriptor.Descriptor(
  name='PmConfigsInfo',
  full_name='voltha.PmConfigsInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.PmConfigsInfo.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pm_configs', full_name='voltha.PmConfigsInfo.pm_configs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1690,
  serialized_end=1763,
)


_SWITCHCAPABILITY = _descriptor.Descriptor(
  name='SwitchCapability',
  full_name='voltha.SwitchCapability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='voltha.SwitchCapability.desc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='switch_features', full_name='voltha.SwitchCapability.switch_features', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1765,
  serialized_end=1879,
)


_IMAGEDOWNLOADMESSAGE = _descriptor.Descriptor(
  name='ImageDownloadMessage',
  full_name='voltha.ImageDownloadMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='voltha.ImageDownloadMessage.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='voltha.ImageDownloadMessage.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1881,
  serialized_end=1973,
)


_OMCITEST = _descriptor.Descriptor(
  name='OMCITest',
  full_name='voltha.OMCITest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='voltha.OMCITest.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='voltha.OMCITest.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1975,
  serialized_end=2059,
)


_SIMULATEALARMMESSAGE = _descriptor.Descriptor(
  name='SimulateAlarmMessage',
  full_name='voltha.SimulateAlarmMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='voltha.SimulateAlarmMessage.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='voltha.SimulateAlarmMessage.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2061,
  serialized_end=2162,
)


_GETEXTVALUEMESSAGE = _descriptor.Descriptor(
  name='GetExtValueMessage',
  full_name='voltha.GetExtValueMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_device', full_name='voltha.GetExtValueMessage.parent_device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_device', full_name='voltha.GetExtValueMessage.child_device', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_type', full_name='voltha.GetExtValueMessage.value_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2165,
  serialized_end=2306,
)


_SETEXTVALUEMESSAGE = _descriptor.Descriptor(
  name='SetExtValueMessage',
  full_name='voltha.SetExtValueMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device', full_name='voltha.SetExtValueMessage.device', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.SetExtValueMessage.value', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2308,
  serialized_end=2393,
)


_OMCIMESSAGE = _descriptor.Descriptor(
  name='OmciMessage',
  full_name='voltha.OmciMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='voltha.OmciMessage.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_status', full_name='voltha.OmciMessage.connect_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_address', full_name='voltha.OmciMessage.proxy_address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_device_id', full_name='voltha.OmciMessage.parent_device_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_device_id', full_name='voltha.OmciMessage.child_device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2396,
  serialized_end=2582,
)


_TECHPROFILEDOWNLOADMESSAGE = _descriptor.Descriptor(
  name='TechProfileDownloadMessage',
  full_name='voltha.TechProfileDownloadMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.TechProfileDownloadMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='voltha.TechProfileDownloadMessage.uni_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance_path', full_name='voltha.TechProfileDownloadMessage.tp_instance_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance', full_name='voltha.TechProfileDownloadMessage.tp_instance', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epon_tp_instance', full_name='voltha.TechProfileDownloadMessage.epon_tp_instance', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tech_tp_instance', full_name='voltha.TechProfileDownloadMessage.tech_tp_instance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2585,
  serialized_end=2819,
)


_DELETEGEMPORTMESSAGE = _descriptor.Descriptor(
  name='DeleteGemPortMessage',
  full_name='voltha.DeleteGemPortMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.DeleteGemPortMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='voltha.DeleteGemPortMessage.uni_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance_path', full_name='voltha.DeleteGemPortMessage.tp_instance_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gem_port_id', full_name='voltha.DeleteGemPortMessage.gem_port_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2821,
  serialized_end=2925,
)


_DELETETCONTMESSAGE = _descriptor.Descriptor(
  name='DeleteTcontMessage',
  full_name='voltha.DeleteTcontMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.DeleteTcontMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='voltha.DeleteTcontMessage.uni_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance_path', full_name='voltha.DeleteTcontMessage.tp_instance_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alloc_id', full_name='voltha.DeleteTcontMessage.alloc_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2927,
  serialized_end=3026,
)


_ONUINDICATIONMESSAGE = _descriptor.Descriptor(
  name='OnuIndicationMessage',
  full_name='voltha.OnuIndicationMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.OnuIndicationMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_indication', full_name='voltha.OnuIndicationMessage.onu_indication', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3028,
  serialized_end=3117,
)


_TECHPROFILEINSTANCEREQUESTMESSAGE = _descriptor.Descriptor(
  name='TechProfileInstanceRequestMessage',
  full_name='voltha.TechProfileInstanceRequestMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.TechProfileInstanceRequestMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance_path', full_name='voltha.TechProfileInstanceRequestMessage.tp_instance_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_device_id', full_name='voltha.TechProfileInstanceRequestMessage.parent_device_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_pon_port', full_name='voltha.TechProfileInstanceRequestMessage.parent_pon_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='voltha.TechProfileInstanceRequestMessage.onu_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='voltha.TechProfileInstanceRequestMessage.uni_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3120,
  serialized_end=3283,
)

_ADAPTERREGISTRATION.fields_by_name['adapter'].message_type = voltha__protos_dot_adapter__pb2._ADAPTER
_ADAPTERREGISTRATION.fields_by_name['dTypes'].message_type = voltha__protos_dot_device__pb2._DEVICETYPES
_PORTFILTER.fields_by_name['port_type'].enum_type = voltha__protos_dot_device__pb2._PORT_PORTTYPE
_DEVICESTATEFILTER.fields_by_name['oper_status'].enum_type = voltha__protos_dot_common__pb2._OPERSTATUS_TYPES
_DEVICESTATEFILTER.fields_by_name['conn_status'].enum_type = voltha__protos_dot_common__pb2._CONNECTSTATUS_TYPES
_PORTSTATE.fields_by_name['port_type'].enum_type = voltha__protos_dot_device__pb2._PORT_PORTTYPE
_PORTSTATE.fields_by_name['oper_status'].enum_type = voltha__protos_dot_common__pb2._OPERSTATUS_TYPES
_PORTSTATEFILTER.fields_by_name['oper_status'].enum_type = voltha__protos_dot_common__pb2._OPERSTATUS_TYPES
_PACKETOUT.fields_by_name['packet'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_PACKET_OUT
_BULKFLOWS.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_BULKFLOWS.fields_by_name['flows'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWS
_BULKFLOWS.fields_by_name['groups'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWGROUPS
_BULKFLOWS.fields_by_name['flow_metadata'].message_type = voltha__protos_dot_voltha__pb2._FLOWMETADATA
_INCREMENTALFLOWS.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_INCREMENTALFLOWS.fields_by_name['flows'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWCHANGES
_INCREMENTALFLOWS.fields_by_name['groups'].message_type = voltha__protos_dot_openflow__13__pb2._FLOWGROUPCHANGES
_INCREMENTALFLOWS.fields_by_name['flow_metadata'].message_type = voltha__protos_dot_voltha__pb2._FLOWMETADATA
_PMCONFIGSINFO.fields_by_name['pm_configs'].message_type = voltha__protos_dot_device__pb2._PMCONFIGS
_SWITCHCAPABILITY.fields_by_name['desc'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_DESC
_SWITCHCAPABILITY.fields_by_name['switch_features'].message_type = voltha__protos_dot_openflow__13__pb2._OFP_SWITCH_FEATURES
_IMAGEDOWNLOADMESSAGE.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_IMAGEDOWNLOADMESSAGE.fields_by_name['image'].message_type = voltha__protos_dot_device__pb2._IMAGEDOWNLOAD
_OMCITEST.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_OMCITEST.fields_by_name['request'].message_type = voltha__protos_dot_voltha__pb2._OMCITESTREQUEST
_SIMULATEALARMMESSAGE.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_SIMULATEALARMMESSAGE.fields_by_name['request'].message_type = voltha__protos_dot_device__pb2._SIMULATEALARMREQUEST
_GETEXTVALUEMESSAGE.fields_by_name['parent_device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_GETEXTVALUEMESSAGE.fields_by_name['child_device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_GETEXTVALUEMESSAGE.fields_by_name['value_type'].enum_type = voltha__protos_dot_common__pb2._VALUETYPE_TYPE
_SETEXTVALUEMESSAGE.fields_by_name['device'].message_type = voltha__protos_dot_device__pb2._DEVICE
_SETEXTVALUEMESSAGE.fields_by_name['value'].message_type = voltha__protos_dot_voltha__pb2._VALUESET
_OMCIMESSAGE.fields_by_name['connect_status'].enum_type = voltha__protos_dot_common__pb2._CONNECTSTATUS_TYPES
_OMCIMESSAGE.fields_by_name['proxy_address'].message_type = voltha__protos_dot_device__pb2._DEVICE_PROXYADDRESS
_TECHPROFILEDOWNLOADMESSAGE.fields_by_name['tp_instance'].message_type = voltha__protos_dot_tech__profile__pb2._TECHPROFILEINSTANCE
_TECHPROFILEDOWNLOADMESSAGE.fields_by_name['epon_tp_instance'].message_type = voltha__protos_dot_tech__profile__pb2._EPONTECHPROFILEINSTANCE
_TECHPROFILEDOWNLOADMESSAGE.oneofs_by_name['tech_tp_instance'].fields.append(
  _TECHPROFILEDOWNLOADMESSAGE.fields_by_name['tp_instance'])
_TECHPROFILEDOWNLOADMESSAGE.fields_by_name['tp_instance'].containing_oneof = _TECHPROFILEDOWNLOADMESSAGE.oneofs_by_name['tech_tp_instance']
_TECHPROFILEDOWNLOADMESSAGE.oneofs_by_name['tech_tp_instance'].fields.append(
  _TECHPROFILEDOWNLOADMESSAGE.fields_by_name['epon_tp_instance'])
_TECHPROFILEDOWNLOADMESSAGE.fields_by_name['epon_tp_instance'].containing_oneof = _TECHPROFILEDOWNLOADMESSAGE.oneofs_by_name['tech_tp_instance']
_ONUINDICATIONMESSAGE.fields_by_name['onu_indication'].message_type = voltha__protos_dot_openolt__pb2._ONUINDICATION
DESCRIPTOR.message_types_by_name['AdapterRegistration'] = _ADAPTERREGISTRATION
DESCRIPTOR.message_types_by_name['ChildDeviceFilter'] = _CHILDDEVICEFILTER
DESCRIPTOR.message_types_by_name['PortFilter'] = _PORTFILTER
DESCRIPTOR.message_types_by_name['DeviceDiscovery'] = _DEVICEDISCOVERY
DESCRIPTOR.message_types_by_name['DeviceStateFilter'] = _DEVICESTATEFILTER
DESCRIPTOR.message_types_by_name['PortState'] = _PORTSTATE
DESCRIPTOR.message_types_by_name['PortStateFilter'] = _PORTSTATEFILTER
DESCRIPTOR.message_types_by_name['PacketIn'] = _PACKETIN
DESCRIPTOR.message_types_by_name['PacketOut'] = _PACKETOUT
DESCRIPTOR.message_types_by_name['DeviceReason'] = _DEVICEREASON
DESCRIPTOR.message_types_by_name['BulkFlows'] = _BULKFLOWS
DESCRIPTOR.message_types_by_name['IncrementalFlows'] = _INCREMENTALFLOWS
DESCRIPTOR.message_types_by_name['PmConfigsInfo'] = _PMCONFIGSINFO
DESCRIPTOR.message_types_by_name['SwitchCapability'] = _SWITCHCAPABILITY
DESCRIPTOR.message_types_by_name['ImageDownloadMessage'] = _IMAGEDOWNLOADMESSAGE
DESCRIPTOR.message_types_by_name['OMCITest'] = _OMCITEST
DESCRIPTOR.message_types_by_name['SimulateAlarmMessage'] = _SIMULATEALARMMESSAGE
DESCRIPTOR.message_types_by_name['GetExtValueMessage'] = _GETEXTVALUEMESSAGE
DESCRIPTOR.message_types_by_name['SetExtValueMessage'] = _SETEXTVALUEMESSAGE
DESCRIPTOR.message_types_by_name['OmciMessage'] = _OMCIMESSAGE
DESCRIPTOR.message_types_by_name['TechProfileDownloadMessage'] = _TECHPROFILEDOWNLOADMESSAGE
DESCRIPTOR.message_types_by_name['DeleteGemPortMessage'] = _DELETEGEMPORTMESSAGE
DESCRIPTOR.message_types_by_name['DeleteTcontMessage'] = _DELETETCONTMESSAGE
DESCRIPTOR.message_types_by_name['OnuIndicationMessage'] = _ONUINDICATIONMESSAGE
DESCRIPTOR.message_types_by_name['TechProfileInstanceRequestMessage'] = _TECHPROFILEINSTANCEREQUESTMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdapterRegistration = _reflection.GeneratedProtocolMessageType('AdapterRegistration', (_message.Message,), {
  'DESCRIPTOR' : _ADAPTERREGISTRATION,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AdapterRegistration)
  })
_sym_db.RegisterMessage(AdapterRegistration)

ChildDeviceFilter = _reflection.GeneratedProtocolMessageType('ChildDeviceFilter', (_message.Message,), {
  'DESCRIPTOR' : _CHILDDEVICEFILTER,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ChildDeviceFilter)
  })
_sym_db.RegisterMessage(ChildDeviceFilter)

PortFilter = _reflection.GeneratedProtocolMessageType('PortFilter', (_message.Message,), {
  'DESCRIPTOR' : _PORTFILTER,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PortFilter)
  })
_sym_db.RegisterMessage(PortFilter)

DeviceDiscovery = _reflection.GeneratedProtocolMessageType('DeviceDiscovery', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEDISCOVERY,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceDiscovery)
  })
_sym_db.RegisterMessage(DeviceDiscovery)

DeviceStateFilter = _reflection.GeneratedProtocolMessageType('DeviceStateFilter', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESTATEFILTER,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceStateFilter)
  })
_sym_db.RegisterMessage(DeviceStateFilter)

PortState = _reflection.GeneratedProtocolMessageType('PortState', (_message.Message,), {
  'DESCRIPTOR' : _PORTSTATE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PortState)
  })
_sym_db.RegisterMessage(PortState)

PortStateFilter = _reflection.GeneratedProtocolMessageType('PortStateFilter', (_message.Message,), {
  'DESCRIPTOR' : _PORTSTATEFILTER,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PortStateFilter)
  })
_sym_db.RegisterMessage(PortStateFilter)

PacketIn = _reflection.GeneratedProtocolMessageType('PacketIn', (_message.Message,), {
  'DESCRIPTOR' : _PACKETIN,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PacketIn)
  })
_sym_db.RegisterMessage(PacketIn)

PacketOut = _reflection.GeneratedProtocolMessageType('PacketOut', (_message.Message,), {
  'DESCRIPTOR' : _PACKETOUT,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PacketOut)
  })
_sym_db.RegisterMessage(PacketOut)

DeviceReason = _reflection.GeneratedProtocolMessageType('DeviceReason', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEREASON,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceReason)
  })
_sym_db.RegisterMessage(DeviceReason)

BulkFlows = _reflection.GeneratedProtocolMessageType('BulkFlows', (_message.Message,), {
  'DESCRIPTOR' : _BULKFLOWS,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.BulkFlows)
  })
_sym_db.RegisterMessage(BulkFlows)

IncrementalFlows = _reflection.GeneratedProtocolMessageType('IncrementalFlows', (_message.Message,), {
  'DESCRIPTOR' : _INCREMENTALFLOWS,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.IncrementalFlows)
  })
_sym_db.RegisterMessage(IncrementalFlows)

PmConfigsInfo = _reflection.GeneratedProtocolMessageType('PmConfigsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PMCONFIGSINFO,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PmConfigsInfo)
  })
_sym_db.RegisterMessage(PmConfigsInfo)

SwitchCapability = _reflection.GeneratedProtocolMessageType('SwitchCapability', (_message.Message,), {
  'DESCRIPTOR' : _SWITCHCAPABILITY,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.SwitchCapability)
  })
_sym_db.RegisterMessage(SwitchCapability)

ImageDownloadMessage = _reflection.GeneratedProtocolMessageType('ImageDownloadMessage', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEDOWNLOADMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ImageDownloadMessage)
  })
_sym_db.RegisterMessage(ImageDownloadMessage)

OMCITest = _reflection.GeneratedProtocolMessageType('OMCITest', (_message.Message,), {
  'DESCRIPTOR' : _OMCITEST,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.OMCITest)
  })
_sym_db.RegisterMessage(OMCITest)

SimulateAlarmMessage = _reflection.GeneratedProtocolMessageType('SimulateAlarmMessage', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATEALARMMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.SimulateAlarmMessage)
  })
_sym_db.RegisterMessage(SimulateAlarmMessage)

GetExtValueMessage = _reflection.GeneratedProtocolMessageType('GetExtValueMessage', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTVALUEMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.GetExtValueMessage)
  })
_sym_db.RegisterMessage(GetExtValueMessage)

SetExtValueMessage = _reflection.GeneratedProtocolMessageType('SetExtValueMessage', (_message.Message,), {
  'DESCRIPTOR' : _SETEXTVALUEMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.SetExtValueMessage)
  })
_sym_db.RegisterMessage(SetExtValueMessage)

OmciMessage = _reflection.GeneratedProtocolMessageType('OmciMessage', (_message.Message,), {
  'DESCRIPTOR' : _OMCIMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.OmciMessage)
  })
_sym_db.RegisterMessage(OmciMessage)

TechProfileDownloadMessage = _reflection.GeneratedProtocolMessageType('TechProfileDownloadMessage', (_message.Message,), {
  'DESCRIPTOR' : _TECHPROFILEDOWNLOADMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.TechProfileDownloadMessage)
  })
_sym_db.RegisterMessage(TechProfileDownloadMessage)

DeleteGemPortMessage = _reflection.GeneratedProtocolMessageType('DeleteGemPortMessage', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGEMPORTMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeleteGemPortMessage)
  })
_sym_db.RegisterMessage(DeleteGemPortMessage)

DeleteTcontMessage = _reflection.GeneratedProtocolMessageType('DeleteTcontMessage', (_message.Message,), {
  'DESCRIPTOR' : _DELETETCONTMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeleteTcontMessage)
  })
_sym_db.RegisterMessage(DeleteTcontMessage)

OnuIndicationMessage = _reflection.GeneratedProtocolMessageType('OnuIndicationMessage', (_message.Message,), {
  'DESCRIPTOR' : _ONUINDICATIONMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.OnuIndicationMessage)
  })
_sym_db.RegisterMessage(OnuIndicationMessage)

TechProfileInstanceRequestMessage = _reflection.GeneratedProtocolMessageType('TechProfileInstanceRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _TECHPROFILEINSTANCEREQUESTMESSAGE,
  '__module__' : 'voltha_protos.inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.TechProfileInstanceRequestMessage)
  })
_sym_db.RegisterMessage(TechProfileInstanceRequestMessage)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
